"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var methods_generator_1 = require("./methods.generator");
var utilities_1 = require("../utilities");
var types_generator_1 = require("./types.generator");
var query_generator_1 = require("./query.generator");
function capitalize(string) {
    return string.charAt(0).toUpperCase() + string.slice(1);
}
exports.createApolloHook = function (_a) {
    var field = _a.field, ObjectTypes = _a.ObjectTypes, prefix = _a.prefix, suffix = _a.suffix, type = _a.type, scalarList = _a.scalarList, renderedFragmentInner = _a.renderedFragmentInner;
    var hasArgs = field.args.length > 0;
    var methodName = field.name;
    var methodArgsType = methods_generator_1.createMethodsArgs(field, prefix, suffix).methodArgsType;
    var isScalar = utilities_1.evaluateType(field).isScalar;
    var returnedTypeDisplay = types_generator_1.getOneTSTypeDisplay({
        field: field,
        prefix: prefix,
        suffix: suffix,
        scalarList: scalarList
    });
    var Query = query_generator_1.queryBuilder({
        field: field,
        isScalar: isScalar,
        prefix: prefix,
        suffix: suffix,
        renderedFragmentInner: renderedFragmentInner,
        type: type
    });
    var TOptions = "" + returnedTypeDisplay + (hasArgs ? ", " + methodArgsType : "");
    var useHookOutput = "";
    if (type.little === "query") {
        useHookOutput = "\n      const {data, ...rest} = use" + type.high + "<" + TOptions + ">(" + type.little + ", options);\n      return {\n        data: data?.[queryName] as " + returnedTypeDisplay + ",\n        ...rest\n      }";
    }
    else {
        useHookOutput = "const [mut, _data] = use" + type.high + "<" + TOptions + ">(" + type.little + ", options);\n      _data.data = _data?.data?.[queryName];\n      return [\n        mut,\n        _data\n      ] as MutationTuple<" + returnedTypeDisplay + (hasArgs ? ", " + methodArgsType : "") + ">";
    }
    if (isScalar) {
        return "\n    use" + capitalize(field.name) + "(options?: " + type.high + "HookOptions<" + TOptions + ">)   {\n      const " + type.little + " = " + Query + "\n      const parsedQuery = " + type.little + ".definitions[0];\n      const queryName = parsedQuery.name.value;\n      " + useHookOutput + "\n    },";
    }
    else {
        return "use" + capitalize(field.name) + "(fragment: string | DocumentNode, options?: " + type.high + "HookOptions<" + TOptions + ">) {\n      const { isString, isFragment, fragmentName } = guessFragmentType(fragment);\n      const " + type.little + " = " + Query + "\n      const parsedQuery = " + type.little + ".definitions[0];\n      const queryName = parsedQuery.name.value;\n\n      " + useHookOutput + "\n    }\n  ,";
    }
};
