"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
var ora_1 = __importDefault(require("ora"));
var prettier = __importStar(require("prettier"));
var fs_1 = __importDefault(require("fs"));
var path_1 = __importDefault(require("path"));
var ts = __importStar(require("typescript"));
var chalk_1 = __importDefault(require("chalk"));
var saveModels = ora_1.default('Saving models file...');
function saveFile(template, output, jsMode) {
    if (output === void 0) { output = './__generated.ts'; }
    saveModels.start();
    return new Promise(function (res, rej) {
        try {
            var formatedModelsFile_1 = prettier.format(template, {
                config: path_1.default.resolve(__dirname, '../.prettierrc'),
                semicolons: true,
                singleQuote: true,
                printWidth: 100,
                bracketSpacing: true,
                parser: 'typescript',
            });
            var outputfile_1 = path_1.default.resolve(process.cwd(), output);
            fs_1.default.writeFile(outputfile_1, formatedModelsFile_1 || template, function (err) {
                if (err) {
                    saveModels.fail('Saving models file failed');
                    console.log(err.message);
                    return rej('error in saving');
                }
                else {
                    saveModels.succeed("\uD83D\uDDC3 Typescript models saved at " + chalk_1.default.bold("" + output));
                    if (jsMode) {
                        try {
                            TypescriptCompile([outputfile_1], {
                                module: ts.ModuleKind.CommonJS,
                                target: ts.ScriptTarget.ESNext,
                                moduleResolution: ts.ModuleResolutionKind.NodeJs,
                                allowSyntheticDefaultImports: true,
                                experimentalDecorators: true,
                                emitDecoratorMetadata: true,
                                resolveJsonModule: true,
                                esModuleInterop: true,
                                removeComments: true,
                                noImplicitAny: false,
                                noUnusedLocals: false,
                                pretty: true,
                                sourceMap: false,
                                downlevelIteration: true,
                                declaration: true,
                                skipLibCheck: true,
                                types: ['node'],
                            });
                            fs_1.default.unlinkSync(outputfile_1);
                            res(formatedModelsFile_1);
                        }
                        catch (e) {
                            rej(e);
                        }
                    }
                    else {
                        res(formatedModelsFile_1);
                    }
                }
            });
        }
        catch (e) {
            saveModels.fail('Saving models file failed');
            return rej(e);
        }
    });
}
exports.saveFile = saveFile;
function TypescriptCompile(fileNames, options) {
    var program = ts.createProgram(fileNames, options);
    program.emit();
}
